import { makeStyles } from "@material-ui/core/styles";
import { IconButton } from "@material-ui/core";
import AudioFileIcon from '@mui/icons-material/AudioFile';
import FileDownloadIcon from '@mui/icons-material/FileDownload';
import { useState } from "react";

import { timeStamp } from '../../../../../../helpers'

const useStyles = makeStyles({
  container: {
      display: "flex",
      justifyContent: "flex-start",
      width:'auto',
      maxWidth: '80%',
      marginBottom:15
  },
  audioWrapper: {
    position: 'relative',
    display: 'flex',
    justifyContent: 'space-between',
    alignContent: 'center',
    alignItems: 'center',
    maxWidth: 300,
    padding: '5px 5px 10px 5px',
    backgroundColor: '#ffffff',
    borderRadius: 7,
      "&:after": {
        content: "''",
        position: "absolute",
        width: "0",
        height: "0",
        borderBottom: "15px solid #ffffff",
        borderLeft: "15px solid transparent",
        borderRight: "15px solid transparent",
        bottom: '0px',
        left: "-15px"
      },
      "&:before": {
        content: "''",
        position: "absolute",
        width: "0",
        height: "0",
        borderBottom: "17px solid #ffffff",
        borderLeft: "16px solid transparent",
        borderRight: "16px solid transparent",
        bottom: "0px",
        left: "-17px"
      }    
  },
  bntDownload: {
    backgroundColor: '#ffffff',
    color:'#54b0fc',
    '&:hover': {
      backgroundColor: '#54b0fc',
      color:'#deffa9'
    }
  },
  title: {
    margin: '0 30px 0 5px',
    color: '#0e0d0d'
  },
  time: {
      position: "absolute",
      fontSize: ".65em",
      fontWeight:600,
      bottom: -10,
      right: -5,
      color: '#ffffff',
      backgroundColor: '#3a3a3a',
      padding: 3,
      borderRadius: 5,
      zIndex:10
    },
});

interface IMessageLeftAudio {
  audioUrl:string,
  updatedAt: string,
}

const MessageLeftAudio = ({ audioUrl,updatedAt }:IMessageLeftAudio) => {
  const classes = useStyles();
  const [change, setChange] = useState<boolean>(false)
  const handleChange = () => setChange(!change)

  return (
    <div className={classes.container}>
      <div className={classes.audioWrapper} onMouseEnter={handleChange} onMouseLeave={handleChange}>
        <AudioFileIcon fontSize='large' style={{ color:'#5f5f5f'}}/>         
        <span className={classes.title}>Audio File</span>
        <a href={`http://localhost:3000/${audioUrl}`} target="_blank" rel="noreferrer">
           <IconButton className={classes.bntDownload}  >
             <FileDownloadIcon fontSize='small'/>
           </IconButton>
        </a>
        <div className={classes.time}>{timeStamp(updatedAt)}</div>
      </div>
    </div>    
)};

export  default  MessageLeftAudio
